__author__ = 'dengjing'
from setuptools import setup, find_packages

setup(
    name='m2mdict',
    version='0.0.3a',
    keywords=('map', 'dict', 'many to many'),
    description = 'a datastruct of many to many',
    license = 'MIT License',
    install_requires = [],
    author = 'dengjing',
    author_email = 'chinadengjing@gmail.com',
    packages = find_packages(),
    platforms = 'any',
)